@@ -1,7 +1,7 @@
 package Sidef {
 
     use 5.014;
-    our $VERSION = '2.30';
+    our $VERSION = '2.300001';
 
     our $SPACES      = 0;    # the current number of spaces
     our $SPACES_INCR = 4;    # the number of spaces incrementor
@@ -17,8 +17,8 @@ package Sidef {
                   SANITIZE_SEC => 3 * 24 * 60 * 60,    # 3 days
                  };
 
-    require List::Util;
-    require File::Spec;
+    use List::Util qw();
+    use File::Spec qw();
 
     use Sidef::Types::Bool::Bool;
     use Sidef::Types::Number::Number;
