@@ -21,13 +21,13 @@ package Sidef::Deparse::Sidef {
                   Sidef::DataTypes::Bool::Bool            Bool
                   Sidef::DataTypes::Array::Array          Array
                   Sidef::DataTypes::Array::Pair           Pair
-                  Sidef::DataTypes::Array::Enumerator     Enumerator
                   Sidef::DataTypes::Array::MultiArray     MultiArray
                   Sidef::DataTypes::Hash::Hash            Hash
                   Sidef::DataTypes::Regex::Regex          Regex
                   Sidef::DataTypes::String::String        String
                   Sidef::DataTypes::Number::Number        Number
                   Sidef::DataTypes::Number::Complex       Complex
+                  Sidef::DataTypes::Range::Range          Range
                   Sidef::DataTypes::Range::RangeNumber    RangeNum
                   Sidef::DataTypes::Range::RangeString    RangeStr
                   Sidef::DataTypes::Block::Block          Block
@@ -42,6 +42,7 @@ package Sidef::Deparse::Sidef {
                   Sidef::DataTypes::Sidef::Sidef          Sidef
                   Sidef::DataTypes::Object::Lazy          Lazy
                   Sidef::DataTypes::Object::LazyMethod    LazyMethod
+                  Sidef::DataTypes::Object::Enumerator    Enumerator
 
                   Sidef::Math::Math                       Math
                   Sidef::Meta::Glob::ARGF                 ARGF
@@ -63,12 +64,11 @@ package Sidef::Deparse::Sidef {
                   Sidef::Time::Time                       Time
                   Sidef::Sys::Sig                         Sig
                   Sidef::Meta::Unimplemented              ...
-
                   )
             },
             %args,
                    );
-        %addr = ();    # reset the addr map
+        %addr = ();    # reset the `addr` hash
         bless \%opts, __PACKAGE__;
     }
 
@@ -194,7 +194,10 @@ package Sidef::Deparse::Sidef {
             }
         }
         elsif ($ref eq 'Sidef::Variable::Variable') {
-            if ($obj->{type} eq 'var' or $obj->{type} eq 'static' or $obj->{type} eq 'const') {
+            if (   $obj->{type} eq 'var'
+                or $obj->{type} eq 'static'
+                or $obj->{type} eq 'const'
+                or $obj->{type} eq 'has') {
                 $code =
                   $obj->{name} =~ /^[0-9]+\z/
                   ? ('$' . $obj->{name})
@@ -269,7 +272,14 @@ package Sidef::Deparse::Sidef {
             $code = 'local ' . '(' . $self->deparse_script($obj->{expr}) . ')';
         }
         elsif ($ref eq 'Sidef::Variable::Global') {
-            $code = 'global ' . $obj->{class} . '::' . $obj->{name},;
+            my $name = 'global ' . $obj->{class} . '::' . $obj->{name};
+            if (not exists($obj->{inited}) and defined($obj->{expr})) {
+                $obj->{inited} = 1;
+                $code = $name . '=' . $self->deparse_script($obj->{expr});
+            }
+            else {
+                $code = $name;
+            }
         }
         elsif ($ref eq 'Sidef::Variable::ClassVar') {
             $code = $self->_dump_reftype($obj->{class}) . '!' . $obj->{name};
@@ -278,7 +288,14 @@ package Sidef::Deparse::Sidef {
             $code = $self->_dump_init_vars($obj, 'var');
         }
         elsif ($ref eq 'Sidef::Variable::ConstInit') {
-            $code = join(";\n" . (" " x $Sidef::SPACES), map { $self->deparse_expr({self => $_}) } @{$obj->{vars}});
+            $code = join(
+                         (
+                          $obj->{type} eq 'global'
+                          ? ', '
+                          : (";\n" . (" " x $Sidef::SPACES))
+                         ),
+                         map { $self->deparse_expr({self => $_}) } @{$obj->{vars}}
+                        );
         }
         elsif ($ref eq 'Sidef::Variable::Define') {
             my $name = $obj->{name};
@@ -527,7 +544,7 @@ package Sidef::Deparse::Sidef {
         elsif (exists $self->{data_types}{$ref}) {
             $code = $self->{data_types}{$ref};
         }
-        elsif ($ref =~ /^Sidef::/ and $obj->can('dump')) {
+        elsif ($ref =~ /^Sidef::/ and UNIVERSAL::can($obj, 'dump')) {
             $code = $obj->dump->get_value;
         }
 
@@ -592,20 +609,11 @@ package Sidef::Deparse::Sidef {
                         }
                     }
                     else {
-
-                        if ($method eq '@') {
-                            $code .= ".$method";
-                        }
-                        elsif ($method eq '@*') {
-                            $code = "\@($code)";
+                        if ($ref eq 'Sidef::Variable::Ref' or $ref eq 'Sidef::Operator::Unary') {
+                            $code .= $method;
                         }
                         else {
-                            if ($ref eq 'Sidef::Variable::Ref' or $ref eq 'Sidef::Object::Unary') {
-                                $code .= $method;
-                            }
-                            else {
-                                $code = "($code) $method ";
-                            }
+                            $code = "($code) $method ";
                         }
                     }
                 }
