@@ -27,7 +27,7 @@ package Sidef::Optimizer {
             exists($INC{$module}) || require($module);
             map {
                 $cache{$package, $_} //= do {
-                    defined(my $method = $package->SUPER::can($_))
+                    defined(my $method = UNIVERSAL::can($package, $_))
                       or die "[ERROR] Invalid method $package: $_";
                     $method;
                   }
@@ -73,7 +73,7 @@ package Sidef::Optimizer {
 
             map {
                 $cache{$type, $_} //= do {
-                    defined(my $method = $type->SUPER::can($_))
+                    defined(my $method = UNIVERSAL::can($type, $_))
                       or die "[ERROR] Invalid method $type: $_";
                     $method;
                   }
@@ -113,7 +113,8 @@ package Sidef::Optimizer {
             (
              map { [$_, [table(STRING)]] }
                methods(STRING, qw(
-                   to downto
+                   to
+                   downto
 
                    concat
                    prepend
@@ -293,8 +294,8 @@ package Sidef::Optimizer {
                    ipow
                    imod
                    range
-                   to
-                   downto
+                   to xto
+                   downto xdownto
 
                    shift_right
                    shift_left
@@ -977,7 +978,7 @@ package Sidef::Optimizer {
                     and exists($rules{$ref_obj})
                     and ref($method) eq '') {
 
-                    my $code = ($cache{$ref_obj, $method} //= $ref_obj->SUPER::can($method));
+                    my $code = ($cache{$ref_obj, $method} //= UNIVERSAL::can($ref_obj, $method));
 
                     if (defined $code) {
                         my $obj_call = $obj->{call}[$i];
