@@ -3,6 +3,8 @@ package Sidef::Types::Array::Array {
     use utf8;
     use 5.016;
 
+    use List::Util qw();
+
     use parent qw(
       Sidef::Object::Object
       );
@@ -335,8 +337,6 @@ package Sidef::Types::Array::Array {
         my $len1 = scalar(@s);
         my $len2 = scalar(@t);
 
-        state $x = require List::Util;
-
         my @d = ([0 .. $len2], map { [$_] } 1 .. $len1);
         foreach my $i (1 .. $len1) {
             foreach my $j (1 .. $len2) {
@@ -366,7 +366,6 @@ package Sidef::Types::Array::Array {
             return 1;
         }
 
-        state $x = require List::Util;
         my $match_distance = int(List::Util::max($s_len, $t_len) / 2) - 1;
 
         my @s_matches;
@@ -1142,7 +1141,6 @@ package Sidef::Types::Array::Array {
 
     sub shuffle {
         my ($self) = @_;
-        state $x = require List::Util;
         $self->new(List::Util::shuffle(@{$self}));
     }
 
