@@ -5,7 +5,9 @@ package Sidef::Types::Glob::Pipe {
       Sidef::Object::Object
       );
 
-    use overload q{""} => \&dump;
+    use overload q{""} => sub {
+        'Pipe(' . join(', ', map { ${Sidef::Types::String::String->new("$_")->dump} } @{$_[0]}) . ')';
+    };
 
     sub new {
         my (undef, @command) = @_;
@@ -24,10 +26,11 @@ package Sidef::Types::Glob::Pipe {
     }
 
     sub open {
+        ref($_[0]) || shift(@_);
         my ($self, $mode, $var_ref) = @_;
 
         if (ref $mode) {
-            $mode = $mode->get_value;
+            $mode = "$mode";
         }
 
         my $pid = open(my $pipe_h, $mode, @{$self});
@@ -45,6 +48,7 @@ package Sidef::Types::Glob::Pipe {
     }
 
     sub open_r {
+        ref($_[0]) || shift(@_);
         my ($self, $var_ref) = @_;
         $self->open('-|:utf8', $var_ref);
     }
@@ -52,6 +56,7 @@ package Sidef::Types::Glob::Pipe {
     *open_read = \&open_r;
 
     sub open_w {
+        ref($_[0]) || shift(@_);
         my ($self, $var_ref) = @_;
         $self->open('|-:utf8', $var_ref);
     }
@@ -60,8 +65,7 @@ package Sidef::Types::Glob::Pipe {
 
     sub dump {
         my ($self) = @_;
-        Sidef::Types::String::String->new(
-                          'Pipe(' . join(', ', map { Sidef::Types::String::String->new($_)->dump->get_value } @{$self}) . ')');
+        Sidef::Types::String::String->new("$self");
     }
 }
 
