@@ -48,6 +48,11 @@ package Sidef::Types::Number::Nan {
     *or          = \&nan;
     *xor         = \&nan;
     *inc         = \&nan;
+    *modpow      = \&nan;
+    *powmod      = \&nan;
+    *expmod      = \&nan;
+    *modinv      = \&nan;
+    *invmod      = \&nan;
     *dec         = \&nan;
     *neg         = \&nan;
     *pos         = \&nan;
@@ -188,6 +193,12 @@ package Sidef::Types::Number::Nan {
 
     *commify = \&dump;
 
+    sub as_rat {
+        state $x = Sidef::Types::String::String->new('0/0');
+    }
+
+    *as_frac = \&as_rat;
+
     sub chr {
         state $x = Sidef::Types::String::String->new('');
     }
@@ -229,8 +240,6 @@ package Sidef::Types::Number::Nan {
 
     *nude = \&parts;
 
-    sub digits { Sidef::Types::Array::Array->new([]) }
-
     {
         no strict 'refs';
         *{__PACKAGE__ . '::' . '/'}   = \&div;
