@@ -33,7 +33,7 @@ package Sidef::Types::Number::Number {
     use overload
       q{bool} => sub { Math::GMPq::Rmpq_sgn(${$_[0]}) != 0 },
       q{0+}   => \&get_value,
-      q{""}   => \&_as_str;
+      q{""}   => \&_big2str;
 
     use Sidef::Types::Bool::Bool;
 
@@ -115,6 +115,9 @@ package Sidef::Types::Number::Number {
     }
 
     sub _big2mpfr {
+
+        $PREC = CORE::int($PREC) if ref($PREC);
+
         my $r = Math::MPFR::Rmpfr_init2($PREC);
         Math::MPFR::Rmpfr_set_q($r, ${$_[0]}, $ROUND);
         $r;
@@ -128,8 +131,6 @@ package Sidef::Types::Number::Number {
 
     sub _mpfr2big {
 
-        $PREC = "$PREC" if ref($PREC);
-
         if (Math::MPFR::Rmpfr_inf_p($_[0])) {
             if (Math::MPFR::Rmpfr_sgn($_[0]) > 0) {
                 return state $x = inf();
@@ -227,18 +228,18 @@ package Sidef::Types::Number::Number {
 
     sub get_value { Math::GMPq::Rmpq_get_d(${$_[0]}) }
 
-    sub _as_str {
-        my $v = Math::GMPq::Rmpq_get_str(${$_[0]}, 10);
-
-        if (index($v, '/') != -1) {
-            my ($x) = @_;
-            $PREC = "$$PREC" if ref($PREC);
+    sub _big2str {
+        my $x = ${$_[0]};
+        Math::GMPq::Rmpq_integer_p($x)
+          ? Math::GMPq::Rmpq_get_str($x, 10)
+          : do {
+            $PREC = CORE::int($PREC) if ref($PREC);
 
             my $prec = CORE::int($PREC / 4);
-            my $sgn  = Math::GMPq::Rmpq_sgn($$x);
+            my $sgn  = Math::GMPq::Rmpq_sgn($x);
 
             my $n = Math::GMPq::Rmpq_init();
-            Math::GMPq::Rmpq_set($n, $$x);
+            Math::GMPq::Rmpq_set($n, $x);
             Math::GMPq::Rmpq_abs($n, $n) if $sgn < 0;
 
             my $z = Math::GMPz::Rmpz_init();
@@ -264,9 +265,9 @@ package Sidef::Types::Number::Number {
             Math::GMPz::Rmpz_set_q($z, $n);
 
             # Too much rounding... Give up and return an MPFR stringified number.
-            Math::GMPz::Rmpz_sgn($z) || do {
+            !Math::GMPz::Rmpz_sgn($z) && $PREC >= 2 && do {
                 my $mpfr = Math::MPFR::Rmpfr_init2($PREC);
-                Math::MPFR::Rmpfr_set_q($mpfr, $$x, $ROUND);
+                Math::MPFR::Rmpfr_set_q($mpfr, $x, $ROUND);
                 return Math::MPFR::Rmpfr_get_str($mpfr, 10, $prec, $ROUND);
             };
 
@@ -311,11 +312,8 @@ package Sidef::Types::Number::Number {
                 push(@r, '0' x $s) if ($s > 0);
             }
 
-            ($sgn < 0 ? "-" : '') . ((shift(@r) . '.' . join('', @r)) =~ s/0+\z//r =~ s/\.\z//r);
-        }
-        else {
-            $v;
-        }
+            ($sgn < 0 ? "-" : '') . shift(@r) . (('.' . join('', @r)) =~ s/0+\z//r =~ s/\.\z//r);
+          }
     }
 
     sub base {
@@ -1804,6 +1802,7 @@ package Sidef::Types::Number::Number {
     }
 
     *expmod = \&modpow;
+    *powmod = \&modpow;
 
     sub modinv {
         my ($x, $y) = @_;
@@ -1902,7 +1901,10 @@ package Sidef::Types::Number::Number {
         my ($x, $y) = @_;
         _valid(\$y);
         my $r = _big2mpz($x);
-        Math::GMPz::Rmpz_bin_si($r, $r, CORE::int(Math::GMPq::Rmpq_get_d($$y)));
+        my $i = CORE::int(Math::GMPq::Rmpq_get_d($$y));
+        $i >= 0
+          ? Math::GMPz::Rmpz_bin_ui($r, $r, $i)
+          : Math::GMPz::Rmpz_bin_si($r, $r, $i);
         _mpz2big($r);
     }
 
